@@ -1,5 +1,15 @@
+# -*- coding: utf-8 -*-
+
 from __future__ import print_function
 
+import os
+from platform import mac_ver
+try:
+    from pkg_resources import parse_version
+except OSError:
+    os.chdir(os.path.expanduser('~'))
+    from pkg_resources import parse_version
+import string
 import sys
 
 import functools
@@ -12,6 +22,10 @@ _log_prefix = ''
 _log_indent = False
 _drop_first_log_prefix = False
 
+_emoji_check_mark = "✅  "
+_emoji_cross_mark = "❌  "
+_is_mac_lion_or_greater = parse_version(mac_ver()[0]) >= parse_version('10.7.0')
+
 
 def ansi(key):
     """Returns the escape sequence for a given ansi color key"""
@@ -24,13 +38,18 @@ def enable_ANSI_colors():
     Populates the global module dictionary `ansi` with ANSI escape sequences.
     """
     global _ansi
-    colors = [
+    color_order = [
         'black', 'red', 'green', 'yellow', 'blue', 'purple', 'cyan', 'white'
     ]
+    short_colors = {
+        'black': 'k', 'red': 'r', 'green': 'g', 'yellow': 'y', 'blue': 'b',
+        'purple': 'p', 'cyan': 'c', 'white': 'w'
+    }
     _ansi = {
-        'escape': '\033', 'reset': 0,
-        'boldon': 1, 'italicson': 3, 'ulon': 4, 'invon': 7,
-        'boldoff': 22, 'italicsoff': 23, 'uloff': 24, 'invoff': 27,
+        'escape': '\033', 'reset': 0, '|': 0,
+        'boldon': 1, '!': 1, 'italicson': 3, '/': 3, 'ulon': 4, '_': 4,
+        'invon': 7, 'boldoff': 22, 'italicsoff': 23,
+        'uloff': 24, 'invoff': 27
     }
 
     # Convert plain numbers to escapes
@@ -39,12 +58,21 @@ def enable_ANSI_colors():
             _ansi[key] = '{0}[{1}m'.format(_ansi['escape'], _ansi[key])
 
     # Foreground
-    for index, color in enumerate(colors):
-        _ansi[color + 'f'] = '{0}[{1}m'.format(_ansi['escape'], 30 + index)
+    for index, color in enumerate(color_order):
+        _ansi[color] = '{0}[{1}m'.format(_ansi['escape'], 30 + index)
+        _ansi[color + 'f'] = _ansi[color]
+        _ansi[short_colors[color] + 'f'] = _ansi[color + 'f']
 
     # Background
-    for index, color in enumerate(colors):
+    for index, color in enumerate(color_order):
         _ansi[color + 'b'] = '{0}[{1}m'.format(_ansi['escape'], 40 + index)
+        _ansi[short_colors[color] + 'b'] = _ansi[color + 'b']
+
+    # Fmt sanitizers
+    _ansi['atexclimation'] = '@!'
+    _ansi['atfwdslash'] = '@/'
+    _ansi['atunderscore'] = '@_'
+    _ansi['atbar'] = '@|'
 
 
 def disable_ANSI_colors():
@@ -56,6 +84,20 @@ def disable_ANSI_colors():
     for key in _ansi:
         _ansi[key] = ''
 
+
+def is_mac_lion_or_greater():
+    global _is_mac_lion_or_greater
+    return _is_mac_lion_or_greater
+
+
+def get_success_prefix():
+    return _emoji_check_mark if _is_mac_lion_or_greater else "@{gf}<== @|"
+
+
+def get_error_prefix():
+    return _emoji_cross_mark if _is_mac_lion_or_greater else "@{rf}@!<== @|"
+
+
 # Default to ansi colors on
 enable_ANSI_colors()
 
@@ -73,7 +115,7 @@ def enable_debug(state=True):
     _debug = state
 
 # Default to debug off
-enable_debug(False)
+enable_debug('DEBUG' in os.environ)
 
 
 def enable_debug_indent(state=True):
@@ -151,7 +193,7 @@ def info(msg, file=None, end='\n', use_prefix=True):
     global _quiet
     msg = str(msg)
     if use_prefix:
-        msg = _log_prefix + msg
+        msg = _log_prefix + msg + ansi('reset')
     if not _quiet:
         print(msg, file=file, end=end)
     return msg
@@ -171,7 +213,7 @@ def warning(msg, file=None, end='\n', use_prefix=True):
     return msg
 
 
-def error(msg, file=None, end='\n', use_prefix=True):
+def error(msg, file=None, end='\n', use_prefix=True, exit=False):
     file = file if file is not None else sys.stderr
     global _quiet
     msg = str(msg)
@@ -179,6 +221,38 @@ def error(msg, file=None, end='\n', use_prefix=True):
         msg = ansi('redf') + ansi('boldon') + _log_prefix + msg + ansi('reset')
     else:
         msg = ansi('redf') + ansi('boldon') + msg + ansi('reset')
+    if exit:
+        sys.exit(msg)
     if not _quiet:
         print(msg, file=file, end=end)
     return msg
+
+
+class ColorTemplate(string.Template):
+    delimiter = '@'
+
+
+def sanitize(msg):
+    """Sanitizes the existing msg, use before adding color annotations"""
+    msg = msg.replace('@', '@@')
+    msg = msg.replace('{', '{{')
+    msg = msg.replace('}', '}}')
+    msg = msg.replace('@@!', '@{atexclimation}')
+    msg = msg.replace('@@/', '@{atfwdslash}')
+    msg = msg.replace('@@_', '@{atunderscore}')
+    msg = msg.replace('@@|', '@{atbar}')
+    return msg
+
+
+def fmt(msg):
+    """Replaces color annotations with ansi escape sequences"""
+    global _ansi
+    msg = msg.replace('@!', '@{boldon}')
+    msg = msg.replace('@/', '@{italicson}')
+    msg = msg.replace('@_', '@{ulon}')
+    msg = msg.replace('@|', '@{reset}')
+    t = ColorTemplate(msg)
+    msg = t.substitute(_ansi) + ansi('reset')
+    msg = msg.replace('{{', '{')
+    msg = msg.replace('}}', '}')
+    return msg
